==> 11.3.0.tar.gz: lib/XWidgets/XItemsComplexWidgets/XBarCodeScanner.dart <==
part of xwidgetbase;

class XBarCodeScanner extends StatefulWidget {
  @override
  State<StatefulWidget> createState() => _QRViewExampleState();
}

class _QRViewExampleState extends State<XBarCodeScanner> {
  Barcode? result;
  QRViewController? controller;
  bool? pausedCamera = false;
  final GlobalKey qrKey = GlobalKey(debugLabel: 'QR');
  @override
  void reassemble() {
    super.reassemble();
    if (Platform.isAndroid) {
      controller!.pauseCamera();
    }
    controller!.resumeCamera();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Column(
        children: <Widget>[
          Expanded(flex: 4, child: _buildQrView(context)),
          Expanded(
            flex: 1,
            child: FittedBox(
              fit: BoxFit.contain,
              child: Column(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: <Widget>[
                  if (result != null) Text('Barcode Type: ${describeEnum(result!.format)}  Data: ${result!.code}') else Text('Scan a code'),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: <Widget>[
                      Container(
                        margin: EdgeInsets.all(8),
                        child: ElevatedButton(
                            onPressed: () async {
                              await controller?.toggleFlash();
                              setState(() {});
                            },
                            child: FutureBuilder(
                              future: controller?.getFlashStatus(),
                              builder: (context, snapshot) {
                                return Text('Luce: ${snapshot.data}');
                              },
                            )),
                      ),
                      Container(
                        margin: EdgeInsets.all(8),
                        child: ElevatedButton(
                            onPressed: () async {
                              await controller?.flipCamera();
                              setState(() {});
                            },
                            child: FutureBuilder(
                              future: controller?.getCameraInfo(),
                              builder: (context, snapshot) {
                                if (snapshot.data != null) {
                                  return Text('Usa Camera Frontale ${describeEnum(snapshot.data!)}');
                                } else {
                                  return Text('caricamento');
                                }
                              },
                            )),
                      )
                    ],
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceAround,
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: <Widget>[
                      XBtnbase(
                          height: 35,
                          width: 180,
                          decoration: XDecoration.circularBox_Gradient_RedAccent(),
                          onPressed: () async {
                            Navigator.pop(context);
                          },
                          label: "Indietro"),
                      SizedBox(width: 30),
                      pausedCamera == true
                          ? XBtnbase(
                              height: 35,
                              width: 180,
                              decoration: XDecoration.circularBox_Gradient_OrangeAccent(),
                              onPressed: () async {
                                setState(() {
                                  pausedCamera = !pausedCamera!;
                                });
                                await controller?.resumeCamera();
                              },
                              label: "Riprendi")
                          : XBtnbase(
                              height: 35,
                              width: 180,
                              decoration: XDecoration.circularBox_Gradient_OrangeAccent(),
                              onPressed: () async {
                                setState(() {
                                  pausedCamera = !pausedCamera!;
                                });
                                await controller?.pauseCamera();
                              },
                              label: "Pausa"),
                    ],
                  ),
                ],
              ),
            ),
          )
        ],
      ),
    );
  }

  Widget _buildQrView(BuildContext context) {
    var scanArea = (MediaQuery.of(context).size.width < 400 || MediaQuery.of(context).size.height < 400) ? 220.0 : 420.0;
    return QRView(
      key: qrKey,
      onQRViewCreated: _onQRViewCreated,
      overlay: QrScannerOverlayShape(borderColor: Colors.red, borderRadius: 10, borderLength: 30, borderWidth: 10, cutOutSize: scanArea),
      onPermissionSet: (ctrl, p) => _onPermissionSet(context, ctrl, p),
    );
  }

  void _onQRViewCreated(QRViewController controller) {
    setState(() {
      this.controller = controller;
    });
    controller.scannedDataStream.listen((scanData) {
      setState(() {
        result = scanData;
        if (result != null) {
          controller.stopCamera(); //mi sa che serve
          Navigator.pop(context, result!.code);
        }
      });
    });
  }

  void _onPermissionSet(BuildContext context, QRViewController ctrl, bool p) {
    log('${DateTime.now().toIso8601String()}_onPermissionSet $p');
    if (!p) {
      ScaffoldMessenger.of(context).showSnackBar(
        SnackBar(content: Text('no Permission')),
      );
    }
  }

  @override
  void dispose() {
    controller?.dispose();
    super.dispose();
  }
}

==> 11.5.9+6.tar.gz: lib/XWidgets/XItemsComplexWidgets/XBarCodeScanner.dart <==
part of xwidgetbase;

class XBarCodeScanner extends StatefulWidget {
  @override
  State<StatefulWidget> createState() => _QRViewExampleState();
}

class _QRViewExampleState extends State<XBarCodeScanner> {
  Barcode? result;
  QRViewController? controller;
  bool? pausedCamera = false;
  final GlobalKey qrKey = GlobalKey(debugLabel: 'QR');
  @override
  void reassemble() {
    super.reassemble();
    if (Platform.isAndroid) {
      controller!.pauseCamera();
    }
    controller!.resumeCamera();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Column(
        children: <Widget>[
          Expanded(flex: 4, child: _buildQrView(context)),
          Expanded(
            flex: 1,
            child: FittedBox(
              fit: BoxFit.contain,
              child: Column(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: <Widget>[
                  if (result != null) Text('Barcode Type: ${describeEnum(result!.format)}  Data: ${result!.code}') else Text('Scan a code'),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: <Widget>[
                      Container(
                        margin: EdgeInsets.all(8),
                        child: ElevatedButton(
                            onPressed: () async {
                              await controller?.toggleFlash();
                              setState(() {});
                            },
                            child: FutureBuilder(
                              future: controller?.getFlashStatus(),
                              builder: (context, snapshot) {
                                return Text('Luce: ${snapshot.data}');
                              },
                            )),
                      ),
                      Container(
                        margin: EdgeInsets.all(8),
                        child: ElevatedButton(
                            onPressed: () async {
                              await controller?.flipCamera();
                              setState(() {});
                            },
                            child: FutureBuilder(
                              future: controller?.getCameraInfo(),
                              builder: (context, snapshot) {
                                if (snapshot.data != null) {
                                  return Text('Usa Camera Frontale ${describeEnum(snapshot.data!)}');
                                } else {
                                  return Text('caricamento');
                                }
                              },
                            )),
                      )
                    ],
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceAround,
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: <Widget>[
                      XBtnbase(
                          height: 35,
                          width: 180,
                          decoration: XDecoration.circularBox_Gradient_RedAccent(),
                          onPressed: () async {
                            Navigator.pop(context);
                          },
                          label: "Indietro"),
                      SizedBox(width: 30),
                      pausedCamera == true
                          ? XBtnbase(
                              height: 35,
                              width: 180,
                              decoration: XDecoration.circularBox_Gradient_OrangeAccent(),
                              onPressed: () async {
                                setState(() {
                                  pausedCamera = !pausedCamera!;
                                });
                                await controller?.resumeCamera();
                              },
                              label: "Riprendi")
                          : XBtnbase(
                              height: 35,
                              width: 180,
                              decoration: XDecoration.circularBox_Gradient_OrangeAccent(),
                              onPressed: () async {
                                setState(() {
                                  pausedCamera = !pausedCamera!;
                                });
                                await controller?.pauseCamera();
                              },
                              label: "Pausa"),
                    ],
                  ),
                ],
              ),
            ),
          )
        ],
      ),
    );
  }

  Widget _buildQrView(BuildContext context) {
    var scanArea = (MediaQuery.of(context).size.width < 400 || MediaQuery.of(context).size.height < 400) ? 220.0 : 420.0;
    return QRView(
      key: qrKey,
      onQRViewCreated: _onQRViewCreated,
      overlay: QrScannerOverlayShape(borderColor: Colors.red, borderRadius: 10, borderLength: 30, borderWidth: 10, cutOutSize: scanArea),
      onPermissionSet: (ctrl, p) => _onPermissionSet(context, ctrl, p),
    );
  }

  void _onQRViewCreated(QRViewController controller) {
    setState(() {
      this.controller = controller;
    });
    controller.scannedDataStream.listen((scanData) {
      setState(() {
        result = scanData;
        if (result != null) {
          controller.stopCamera(); //mi sa che serve
          Navigator.pop(context, result!.code);
        }
      });
    });
  }

  void _onPermissionSet(BuildContext context, QRViewController ctrl, bool p) {
    // log('${DateTime.now().toIso8601String()}_onPermissionSet $p');
    if (!p) {
      ScaffoldMessenger.of(context).showSnackBar(
        SnackBar(content: Text('no Permission')),
      );
    }
  }

  @override
  void dispose() {
    controller?.dispose();
    super.dispose();
  }
}
